#[unsafe(no_mangle)]pub unsafe extern "C" fn cove_compile(
source: *const u8,
len: usize,
) -> *mut u8Expand description
Checks and lowers source, and answers the diagnostics and the
disassembly as an answer block. See crate::compile_json.
Safety
source must point at len initialized bytes inside this module’s
memory. They are read and not retained; the caller still owns them.